==> kube-integration-1.1.11.tgz: package/lib/kube-native/pod/tests/pod.unit.spec.js <==
'use strict';

const chai = require('chai');
const sinonChai = require('sinon-chai');
const _ = require('lodash');
const Pod = require('./../pod');

const expect = chai.expect;
chai.use(sinonChai);


function getFakePod(){
    return new Pod({
        "apiVersion": "v1",
        "kind": "Pod",
        "metadata": {
            "labels": {
                "app": "fake-app",
            },
            "name": "fake-app-replica-id-pod-generater-number",
            "namespace": "default",
            "ownerReferences": [
                {
                    "apiVersion": "extensions/v1beta1",
                    "blockOwnerDeletion": true,
                    "controller": true,
                    "kind": "ReplicaSet",
                    "name": "fake-app-replica-id",
                }
            ],
        },
        "spec": {
            "containers": [
                {
                    "image": "fake-image",
                    "name": "fake-container-name",
                }
            ],
        },
        "status": {
            "containerStatuses": [
                {
                    "containerID": "docker://4eb986670f2a42692db45a9aa102d644bb7f52ecc418d91e24a6bd405ad90d67",
                    "image": "fake-image",
                    "imageID": "docker://sha256:a2cebe2f993991e4a679a5f3c7bc8bdd1e6d69ae586f01714ccdb016db2f593c",
                    "lastState": {},
                    "name": "cfinternalstatuspage",
                    "ready": true,
                    "restartCount": 0,
                    "state": {
                        "running": {
                            "startedAt": "2017-11-14T09:03:20Z"
                        }
                    }
                },
                {
                    "containerID": "docker://4eb986670f2a42692db45a9aa102d644bb7f52ecc418d91e24a6bd405ad90d67",
                    "image": "fake-image",
                    "imageID": "docker-pullable://r.cfcr.io/innolert/innolert/innolertapi@sha256:23af86c090637983e6d1efd35b841c58d7794a8794eb762ba612258f522cb543",
                    "lastState": {},
                    "name": "cfinternalstatuspage",
                    "ready": true,
                    "restartCount": 0,
                    "state": {
                        "running": {
                            "startedAt": "2017-11-14T09:03:20Z"
                        }
                    }
                }
            ],
        }
    });
}

describe('Pod', () => {
    it('Should get image ids', () => {
        const pod = getFakePod();
        expect(pod.getImages()).to.be.deep.equal([
            {
                "id": "a2cebe2f993991e4a679a5f3c7bc8bdd1e6d69ae586f01714ccdb016db2f593c",
                "name": "fake-image",
            },
            {
                "id": "23af86c090637983e6d1efd35b841c58d7794a8794eb762ba612258f522cb543",
                "name": "fake-image",
            }
        ]);
    });
});

==> kube-integration-1.1.12.tgz: package/lib/kube-native/pod/tests/pod.unit.spec.js <==
'use strict';

const chai = require('chai');
const sinonChai = require('sinon-chai');
const _ = require('lodash');
const Pod = require('./../pod');

const expect = chai.expect;
chai.use(sinonChai);


function getFakePod(){
    return new Pod({
        "apiVersion": "v1",
        "kind": "Pod",
        "metadata": {
            "labels": {
                "app": "fake-app",
            },
            "name": "fake-app-replica-id-pod-generater-number",
            "namespace": "default",
            "ownerReferences": [
                {
                    "apiVersion": "extensions/v1beta1",
                    "blockOwnerDeletion": true,
                    "controller": true,
                    "kind": "ReplicaSet",
                    "name": "fake-app-replica-id",
                }
            ],
        },
        "spec": {
            "containers": [
                {
                    "image": "fake-image",
                    "name": "fake-container-name",
                }
            ],
        },
        "status": {
            "containerStatuses": [
                {
                    "containerID": "docker://4eb986670f2a42692db45a9aa102d644bb7f52ecc418d91e24a6bd405ad90d67",
                    "image": "fake-image",
                    "imageID": "docker://sha256:a2cebe2f993991e4a679a5f3c7bc8bdd1e6d69ae586f01714ccdb016db2f593c",
                    "lastState": {},
                    "name": "cfinternalstatuspage",
                    "ready": true,
                    "restartCount": 0,
                    "state": {
                        "running": {
                            "startedAt": "2017-11-14T09:03:20Z"
                        }
                    }
                },
                {
                    "containerID": "docker://4eb986670f2a42692db45a9aa102d644bb7f52ecc418d91e24a6bd405ad90d67",
                    "image": "fake-image",
                    "imageID": "docker-pullable://r.cfcr.io/innolert/innolert/innolertapi@sha256:23af86c090637983e6d1efd35b841c58d7794a8794eb762ba612258f522cb543",
                    "lastState": {},
                    "name": "cfinternalstatuspage",
                    "ready": true,
                    "restartCount": 0,
                    "state": {
                        "running": {
                            "startedAt": "2017-11-14T09:03:20Z"
                        }
                    }
                }
            ],
        }
    });
}

describe('Pod', () => {
    it('Should get image ids', () => {
        const pod = getFakePod();
        expect(pod.getImages()).to.be.deep.equal([
            {
                "imageID": "a2cebe2f993991e4a679a5f3c7bc8bdd1e6d69ae586f01714ccdb016db2f593c",
                "name": "fake-image",
            },
            {
                "imageID": "23af86c090637983e6d1efd35b841c58d7794a8794eb762ba612258f522cb543",
                "name": "fake-image",
            }
        ]);
    });
});
